@@ -5,6 +5,6 @@ use strict;
 use warnings;
 
 use lib 'lib';
-use Wx::Perl::Dialog;
+use Wx::Perl::Dialog::Simple;
 
 print map {"$_\n"} choice( choices => [qw(a b c)] );
